Functions for validation
=========================

With pcrglobwb_utils it is possible to validate spatially-varying PCR-GLOBWB output against a range of datasets. Per domain, area averages per timestep are computed and timeseries validated.

.. autoclass:: spatial_validation.validate_per_shape
    :members: